@@ -1,17 +1,17 @@
 balanced.pcdesign <- function(nstimuli){
   # Create a (completely) balanced paired-comparison design
-  # Last mod: Mar/19/2008, FW
+  # Last mod: Sep/30/2009, FW
 
   t <- nstimuli
   if(t < 3 | t > 26) stop("nstimuli must lie between 3 and 26")
 
-  if(t %% 2 != 0){  # t odd, completely balanced design
+  if(t %% 2){  # t odd, completely balanced design
     m1 <- matrix(letters[1:t], t, .5*(t + 1), TRUE)
     m2 <- matrix(letters[1:t], t, ncol(m1) - 1, TRUE)
     m2 <- as.matrix(m2[nrow(m2):1, ncol(m2):1])
     X <- cbind(m1[,1], matrix(paste(m2, m1[,-1], sep=""), nrow(m2), ncol(m2)))
     A <- as.character(t(X[,-1]))
-  }else{            # t even, design is not completely balanced
+  }else{       # t even, design is not completely balanced
     t <- t - 1
     m1 <- matrix(letters[1:t], t, .5*(t + 1), TRUE)
     m2 <- matrix(letters[1:t], t, ncol(m1) - 1, TRUE)
